@@ -14,6 +14,7 @@
 #include <KPublicTransport/OnboardStatus>
 
 #include <QFile>
+#include <QJsonArray>
 #include <QJsonDocument>
 #include <QJsonObject>
 #include <QNetworkRequest>
@@ -61,6 +62,7 @@ private Q_SLOTS:
         QTest::newRow("ana") << s("panasonic-inflight-v1") << s("../onboard-journey/ana.in.json") << 39.3520f << 141.077f << 801.916f << 191.0f;
         QTest::newRow("united") << s("panasonic-inflight-v1") << s("../onboard-journey/united.in.json") << 41.5150f << 2.069f << 872.292f << 169.0f;
         QTest::newRow("cathay-pacific") << s("panasonic-inflight-v2") << s("../onboard-journey/cathay-pacific.in.json") << 23.198333f << 118.836667f << 755.616f << 231.0f;
+        QTest::newRow("aegean") << s("aegean") << s("aegean.json") << 47.96723323f << 11.781437752f << 1007.0f << 137.0f;
     }
 
     void testScriptedPositionParsers()
@@ -80,9 +82,14 @@ private Q_SLOTS:
 
         QFile f(QLatin1String(SOURCE_DIR) + QLatin1String("/data/onboard-position/") + inputFile);
         QVERIFY(f.open(QFile::ReadOnly));
-        const auto inputObj = QJsonDocument::fromJson(f.readAll()).object();
+        const auto inputDoc = QJsonDocument::fromJson(f.readAll());
 
-        const auto pos = restApi->parsePositionData(inputObj);
+        PositionData pos;
+        if (inputDoc.isArray()) {
+            pos = restApi->parsePositionData(inputDoc.array());
+        } else {
+            pos = restApi->parsePositionData(inputDoc.object());
+        }
         QCOMPARE(pos.latitude, lat);
         QCOMPARE(pos.longitude, lon);
         QCOMPARE(pos.speed, speed);
@@ -97,6 +104,7 @@ private Q_SLOTS:
         QTest::newRow("cd-railjet") << s("ceskedrahy") << s("cd-railjet");
         QTest::newRow("db-ice") << s("deutschebahn-ice") << s("db-ice");
         QTest::newRow("db-zugportal") << s("deutschebahn-zugportal") << s("db-zugportal");
+        QTest::newRow("db-zugportal-canceled") << s("deutschebahn-zugportal") << s("db-zugportal-canceled");
         QTest::newRow("sncf-inoui") << s("sncf-tgv") << s("sncf-inoui");
         QTest::newRow("sbb") << s("sbb") << s("sbb");
 
@@ -118,15 +126,55 @@ private Q_SLOTS:
 
         QFile inputFile(QLatin1String(SOURCE_DIR) + QLatin1String("/data/onboard-journey/") + testFile + QLatin1String(".in.json"));
         QVERIFY(inputFile.open(QFile::ReadOnly));
-        const auto inputObj = QJsonDocument::fromJson(inputFile.readAll()).object();
 
-        const auto jny = restApi->parseJourneyData(inputObj);
+        const auto inputDoc = QJsonDocument::fromJson(inputFile.readAll());
+        Journey jny;
+        if (inputDoc.isArray()) {
+            jny = restApi->parseJourneyData(inputDoc.array());
+        } else {
+            jny = restApi->parseJourneyData(inputDoc.object());
+        }
+
         const auto jsonRes = Journey::toJson(jny);
 
         const QString refFileName = QLatin1String(SOURCE_DIR) + QLatin1String("/data/onboard-journey/") + testFile + QLatin1String(".out.json");
         const auto ref = QJsonDocument::fromJson(Test::readFile(refFileName)).object();
         QVERIFY(Test::compareJson(refFileName, jsonRes, ref));
     }
+
+    void testScriptedSupport_data()
+    {
+        QTest::addColumn<QString>("backendId");
+        QTest::addColumn<bool>("supportsPosition");
+        QTest::addColumn<bool>("supportsJourney");
+
+        QTest::newRow("cd-railjet") << s("ceskedrahy") << true << true;
+        QTest::newRow("db-ice") << s("deutschebahn-ice") << true << true;
+        QTest::newRow("db-zugportal") << s("deutschebahn-zugportal") << false << true;
+        QTest::newRow("sncf-inoui") << s("sncf-tgv") << true << true;
+        QTest::newRow("sbb") << s("sbb") << true << true;
+        QTest::newRow("thalys") << s("icomera-omboard") << true << false;
+
+        QTest::newRow("ana") << s("panasonic-inflight-v1") << true << true;
+        QTest::newRow("united") << s("panasonic-inflight-v1") << true << true;
+        QTest::newRow("cathay-pacific") << s("panasonic-inflight-v2") << true << true;
+        QTest::newRow("aegean") << s("aegean") << true << false;
+    }
+
+    void testScriptedSupport()
+    {
+        QFETCH(QString, backendId);
+        QFETCH(bool, supportsPosition);
+        QFETCH(bool, supportsJourney);
+
+        auto backend = OnboardStatusManager::createBackend(backendId);
+        QVERIFY(backend);
+        auto restApi = qobject_cast<const RestOnboardBackend*>(backend.get());
+        QVERIFY(restApi);
+
+        QCOMPARE(restApi->supportsPosition(), supportsPosition);
+        QCOMPARE(restApi->supportsJourney(), supportsJourney);
+    }
 };
 
 QTEST_GUILESS_MAIN(OnboardStatusTest)
