@@ -129,6 +129,26 @@ static void preProcessCoverage(QJsonObject &obj)
             poly = PolygonSimplifier::offset(poly, 10'000.0);
         }
     }
+
+    // remove polygons fully contained inside another one already (e.g. small enclaves/islands included by the above offset operation now)
+    for (auto it = polys.begin(); it != polys.end();) {
+        auto it2 = polys.begin();
+        for (; it2 != polys.end(); ++it2) {
+            if (it == it2) {
+                continue;
+            }
+            if ((*it).subtracted(*it2).isEmpty()) {
+                break;
+            }
+        }
+        if (it2 != polys.end()) {
+            qDebug() << "dropping fully enclosed polygon" << (*it).size();
+            it = polys.erase(it);
+        } else {
+            ++it;
+        }
+    }
+
     if (!polys.empty()) {
         obj.insert(QLatin1String("area"), GeoJson::writePolygons(polys));
     }
@@ -180,6 +200,16 @@ static void postProcessConfig(QJsonObject &top)
     }
 }
 
+static QByteArray postProcessJson(const QByteArray &data)
+{
+    // fold arrays of scalar values into one line
+    auto s = QString::fromUtf8(data);
+    s = s.replace(QRegularExpression(QStringLiteral("\\[\n +(\"[A-Za-z-]+\"|[\\d\\.-]+)")), QStringLiteral("[\\1"));
+    s = s.replace(QRegularExpression(QStringLiteral(",\n +(\"[A-Za-z-]+\"|[\\d\\.-]+)(?=[,\n])")), QStringLiteral(", \\1"));
+    s = s.replace(QRegularExpression(QStringLiteral("(?<![,\\]}])\n +](\n|,\n)")), QStringLiteral("]\\1"));
+    return s.toUtf8();
+}
+
 static bool applyUpstreamConfig(const QString &kptConfigFile, const QString &apiConfigFile)
 {
     qDebug() << "merging" << apiConfigFile << kptConfigFile;
@@ -211,7 +241,7 @@ static bool applyUpstreamConfig(const QString &kptConfigFile, const QString &api
         std::cerr << qPrintable(outFile.errorString()) << std::endl;
         return false;
     }
-    outFile.write(QJsonDocument(outObj).toJson());
+    outFile.write(postProcessJson(QJsonDocument(outObj).toJson()));
     return true;
 }
 
